@@ -11,7 +11,10 @@ import os
 import re
 # TODO  create also oo hash that saves all needed data, so [o,oo] contains all need to save an open anything
 # from TextEditor import TextEditor as HTMLEDITOR
-from AWidget import AWidget
+try:
+    from AWidget import AWidget
+except:
+    from Encrypt_Lab.AWidget import AWidget
 # from codeeditor import QCodeEditor
 # from code_editor.d import CodeEditor
 
